==> nextcloud-25.0.11.tgz: nextcloud/apps/systemtags/l10n/zh_HK.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "標籤名稱為空",
    "Update" : "更新",
    "Create" : "新增",
    "Select tag …" : "選擇標籤…",
    "System tag %1$s added by the system" : "系統添加的系統標籤 %1$s",
    "Added system tag {systemtag}" : "已加入系統標籤 {systemtag}",
    "Added system tag %1$s" : "已加入系統標籤 %1$s",
    "%1$s added system tag %2$s" : "%1$s已加入系統標籤 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已加入系統標籤 {systemtag}",
    "System tag %1$s removed by the system" : "系統已將系統標籤 %1$s 刪除",
    "Removed system tag {systemtag}" : "已移除系統標籤 {systemtag}",
    "Removed system tag %1$s" : "已移除系統標籤 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 已移除系統標籤 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 已移除系統標籤 {systemtag}",
    "You created system tag %1$s" : "您新增了系統標籤 %1$s",
    "You created system tag {systemtag}" : "您新增了系統標籤 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 新增了系統標籤 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 新增了系統標籤 {systemtag}",
    "You deleted system tag %1$s" : "您刪除了系統標籤 %1$s",
    "You deleted system tag {systemtag}" : "您刪除了系統標籤 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s刪除了系統標籤 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 刪除了系統標籤 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您更新了系統標籤 %2$s 為 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您更新了系統標籤 {oldsystemtag} 為 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 更新了系統標籤 %3$s 為 %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 更新了系統標籤 {oldsystemtag} 為 {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "系統已將系統標籤%2$s添加到%1$s",
    "System tag {systemtag} was added to {file} by the system" : "系統已將系統標籤 {systemtag} 添加到 {file}",
    "You added system tag %2$s to %1$s" : "您已將系統標籤  %2$s 添加到 %1$s",
    "You added system tag {systemtag} to {file}" : "系統已將系統標籤 {systemtag} 添加到 {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s 添加了系統標籤 %3$s 到 %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 已將系統標籤 {systemtag} 添加到 {file}",
    "System tag %2$s was removed from %1$s by the system" : "系統標籤 %2$s 已被系統從 %1$s 移除",
    "System tag {systemtag} was removed from {file} by the system" : "系統標籤 {systemtag} 已被系統從 {file} 移除",
    "You removed system tag %2$s from %1$s" : "系統標籤 %2$s 已被您從 %1$s 移除",
    "You removed system tag {systemtag} from {file}" : "系統標籤 {systemtag} 已被您從 {file} 移除",
    "%1$s removed system tag %3$s from %2$s" : "系統標籤 %3$s 已被 %1$s 從 %2$s 移除",
    "{actor} removed system tag {systemtag} from {file}" : "系統標籤 {systemtag} 已被 {actor} 從 {file} 移除",
    "%s (restricted)" : "%s （受限）",
    "%s (invisible)" : "%s （隱藏）",
    "<strong>System tags</strong> for a file have been modified" : "一個檔案的<strong>系統標籤</strong>已經被修改",
    "Tags" : "標籤",
    "All tagged %s …" : "所有標記為 %s ...",
    "tagged %s" : "標記為 %s ...",
    "Collaborative tags" : "協作標籤",
    "Collaborative tagging functionality which shares tags among users." : "協作標記允許用戶分享標記。",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "協作標記允許用戶分享標記。適合團隊使用。\n\t（如果您是多租戶安裝的提供商，由於標籤是共享的，因此建議您停用此應用程序。）",
    "Loading collaborative tags …" : "正在載入協作標籤 ...",
    "Search or create collaborative tags" : "搜索或創建協作標籤",
    "Collaborative tags …" : "協作的標籤 ...",
    "No tags to select, type to create a new tag" : "沒有可供選擇的標籤，鍵入以創建新標籤",
    "Failed to load tags" : "載入標記失敗",
    "Failed to load selected tags" : "無法加載所選的標籤",
    "Failed to select tag" : "無法選擇標籤",
    "Failed to create tag" : "創建標籤失敗",
    "Failed to delete tag" : "刪除標籤失敗",
    "This file has the tag {tag}" : "此檔案有標籤 {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "此檔案有標籤 {firstTags} 與 {lastTag}",
    "Failed to load last used tags" : "無法加載上次使用的標籤",
    "Missing \"Content-Location\" header" : "缺少 “Content-Location” 標頭",
    "Tagged files" : "已標籤檔案",
    "Select tags to filter by" : "依照選擇的標籤篩選",
    "No tags found" : "找不到標籤",
    "Please select tags to filter by" : "請選擇標籤以篩選",
    "No files found for the selected tags" : "沒有與已選標籤相符的檔案",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "協作標籤可以被所有用戶使用。受限標籤是可見的，但用戶無法分配它們。不可見標籤僅供內部使用，用戶既看不到也無法分配它們。",
    "Create a new tag" : "建立新標籤",
    "Name" : "名稱",
    "Public" : "公開",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Delete" : "移除",
    "Reset" : "重設",
    "No files in here" : "此處沒有任何檔案",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Size" : "大小",
    "Modified" : "修改時間"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.12p1.tgz: nextcloud/apps/systemtags/l10n/zh_HK.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "標籤名稱為空",
    "Update" : "更新",
    "Create" : "新增",
    "Select tag …" : "選擇標籤…",
    "System tag %1$s added by the system" : "系統添加的系統標籤 %1$s",
    "Added system tag {systemtag}" : "已加入系統標籤 {systemtag}",
    "Added system tag %1$s" : "已加入系統標籤 %1$s",
    "%1$s added system tag %2$s" : "%1$s已加入系統標籤 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已加入系統標籤 {systemtag}",
    "System tag %1$s removed by the system" : "系統已將系統標籤 %1$s 刪除",
    "Removed system tag {systemtag}" : "已移除系統標籤 {systemtag}",
    "Removed system tag %1$s" : "已移除系統標籤 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 已移除系統標籤 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 已移除系統標籤 {systemtag}",
    "You created system tag %1$s" : "您新增了系統標籤 %1$s",
    "You created system tag {systemtag}" : "您新增了系統標籤 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 新增了系統標籤 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 新增了系統標籤 {systemtag}",
    "You deleted system tag %1$s" : "您刪除了系統標籤 %1$s",
    "You deleted system tag {systemtag}" : "您刪除了系統標籤 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s刪除了系統標籤 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 刪除了系統標籤 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您更新了系統標籤 %2$s 為 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您更新了系統標籤 {oldsystemtag} 為 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 更新了系統標籤 %3$s 為 %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 更新了系統標籤 {oldsystemtag} 為 {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "系統已將系統標籤%2$s添加到%1$s",
    "System tag {systemtag} was added to {file} by the system" : "系統已將系統標籤 {systemtag} 添加到 {file}",
    "You added system tag %2$s to %1$s" : "您已將系統標籤  %2$s 添加到 %1$s",
    "You added system tag {systemtag} to {file}" : "系統已將系統標籤 {systemtag} 添加到 {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s 添加了系統標籤 %3$s 到 %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 已將系統標籤 {systemtag} 添加到 {file}",
    "System tag %2$s was removed from %1$s by the system" : "系統標籤 %2$s 已被系統從 %1$s 移除",
    "System tag {systemtag} was removed from {file} by the system" : "系統標籤 {systemtag} 已被系統從 {file} 移除",
    "You removed system tag %2$s from %1$s" : "系統標籤 %2$s 已被您從 %1$s 移除",
    "You removed system tag {systemtag} from {file}" : "系統標籤 {systemtag} 已被您從 {file} 移除",
    "%1$s removed system tag %3$s from %2$s" : "系統標籤 %3$s 已被 %1$s 從 %2$s 移除",
    "{actor} removed system tag {systemtag} from {file}" : "系統標籤 {systemtag} 已被 {actor} 從 {file} 移除",
    "%s (restricted)" : "%s （受限）",
    "%s (invisible)" : "%s （隱藏）",
    "<strong>System tags</strong> for a file have been modified" : "一個檔案的<strong>系統標籤</strong>已經被修改",
    "Tags" : "標籤",
    "All tagged %s …" : "所有標記為 %s ...",
    "tagged %s" : "標記為 %s ...",
    "Collaborative tags" : "協作標籤",
    "Collaborative tagging functionality which shares tags among users." : "協作標記允許用戶分享標記。",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "協作標記允許用戶分享標記。適合團隊使用。\n\t（如果您是多租戶安裝的提供商，由於標籤是共享的，因此建議您停用此應用程序。）",
    "Loading collaborative tags …" : "正在載入協作標籤 ...",
    "Search or create collaborative tags" : "搜索或創建協作標籤",
    "Collaborative tags …" : "協作的標籤 ...",
    "No tags to select, type to create a new tag" : "沒有可供選擇的標籤，鍵入以創建新標籤",
    "Failed to load tags" : "載入標記失敗",
    "Failed to load selected tags" : "無法加載所選的標籤",
    "Failed to select tag" : "無法選擇標籤",
    "Failed to create tag" : "創建標籤失敗",
    "Failed to delete tag" : "刪除標籤失敗",
    "This file has the tag {tag}" : "此檔案帶有 {tag} 標籤",
    "This file has the tags {firstTags} and {lastTag}" : "此檔案帶有 {firstTags} 及 {lastTag} 標籤",
    "No tags found" : "找不到標籤",
    "Failed to load last used tags" : "無法加載上次使用的標籤",
    "Missing \"Content-Location\" header" : "缺少 “Content-Location” 標頭",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "協作標籤可以被所有用戶使用。受限標籤是可見的，但用戶無法分配它們。不可見標籤僅供內部使用，用戶既看不到也無法分配它們。",
    "Create a new tag" : "建立新標籤",
    "Name" : "名稱",
    "Public" : "公開",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Delete" : "移除",
    "Reset" : "重設",
    "No files in here" : "此處沒有任何檔案",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Size" : "大小",
    "Modified" : "修改時間",
    "Tagged files" : "已標籤檔案",
    "Select tags to filter by" : "依照選擇的標籤篩選",
    "Please select tags to filter by" : "請選擇標籤以篩選",
    "No files found for the selected tags" : "沒有與已選標籤相符的檔案"
},
"nplurals=1; plural=0;");
